@@ -13,34 +13,59 @@ class Material:
     as long as the method to write material to file
 
     :param name: material name
+
     :type name: str
+
     :param nuclides: list of nuclides the material consists of, defaults to None
+
     :type nuclides: one-dimensional list of strings
+
     :param concentrations: list of nuclides' concentrations, defaults to None
+
     :type concentrations: one-dimensional list of floats, len(concentrations)==len(nuclides)
+
     :param density: material density, defaults to 'sum'
+
     :type density: str or float
+
     :param temp: material temperature, defaults to 600
+
     :type temp: int or float
+
     :param color: color of the material in Serpent, defaults to None
+
     :type color: one-dimensional list of integers from 0 to 255
+
     :param burn: burnable material indicator, defaults to 0
+
     :type burn: integer, possible values 0 or 1
+
     :param is_coolant: indicates if material represents water-based coolant, if yes lwtr card will be added to material
+
     :type is_coolant: bool
+
     :param is_fuel: indicates if material represents fuel
+
     :type is_fuel: bool
+
     :param nuclides_format: the format of the parameter nuclides, possible values: "Mendeleev_table" or "Serpent".
         Defaults to "Mendeleev_table".
+
     :type nuclides_format: str
+
     :var nuclides_dict: dictionary with the Serpent representation of nuclides names
+
     :type nuclides_dict: dictionary, keys are str names of the nuclides ('H-1', 'Gd-152', ..)
         values are str names of nuclides in Serpent ('1001', '8016', ..)
+
     :var nuclides_concentrations: dictionary with the nuclide-concentration values
+
     :type nuclides_concentrations: dictionary, keys are str names of nuclides in Serpent ('1001', '8016', ..)
         values are lists with len==2, value[0] is a float (nuclide concentration),
         value[1] is a str (name of the nuclide)
+
     :var lines: Serpent representation of material
+
     :type lines: list[str]
     """
 
@@ -50,10 +75,12 @@ class Material:
     def write_instances_to_file(cls, filename):
         """
         Class method to write all instances into the file
+
         :param filename: name of the file
+
         :type filename: str
+
         :return: None
-        :rtype: None
         """
         with open(filename, 'w') as file:
             for instance in cls.instances:
@@ -118,8 +145,8 @@ class Material:
             pass
         else:
             logger.error(f"Something went wrong, "
-                                 f"the length of nuclides and concentrations lists must be equal, "
-                                 f"execution will be stoped")
+                         f"the length of nuclides and concentrations lists must be equal, "
+                         f"execution will be stoped")
             raise AttributeError(f"Something went wrong, "
                                  f"the length of nuclides and concentrations lists must be equal, "
                                  f"execution will be stoped")
@@ -185,7 +212,9 @@ class Material:
     def write_to_file(self, file) -> None:
         """
         Method writes the material in the form of Serpent material input description
+
         :param file: the file object to write material into
+
         :type file: file object
         """
         file.writelines(self.lines)
